
Pseudo Random List Generator (PRLGEN) v2.0
==========================================

A Python package for generating maximal entropy stimulus lists for psycholinguistic and cognitive experiments.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   motivation
   installation
   usage
   api
   proof
   license
